WriteConfig

Struct WriteConfig 

pub struct WriteConfig<'a> {
    pub print_to_cli: bool,
    pub output_file: File,
    pub metadata_args: MetadataArgs<'a>,
    pub m_type: MeasurementType,
    pub is_multi_origin: bool,
    pub worker_map: BiHashMap<u32, String>,
    pub is_chaos: bool,
    pub is_sessions: bool,
}
Configuration for the results writing process.

Fields

print_to_cli: bool

Determines whether the results should also be printed to the command-line interface.

output_file: File

The file handle to which the measurement results should be written.

metadata_args: MetadataArgs<'a>

Metadata for the measurement, to be written at the beginning of the output file.

m_type: MeasurementType

Measurement type

is_multi_origin: bool

Indicates whether the measurement involves multiple origins

worker_map: BiHashMap<u32, String>

A bidirectional map used to convert worker IDs (u16) to their corresponding hostnames (String).

is_chaos: bool

Indicate whether any Origin is for CHAOS

is_sessions: bool

Whether feed sessions are enabled (–sessions; adds a ‘session’ column to feed output)