pub struct WriteConfig<'a> {
pub print_to_cli: bool,
pub output_file: File,
pub metadata_args: MetadataArgs<'a>,
pub m_type: MeasurementType,
pub is_multi_origin: bool,
pub worker_map: BiHashMap<u32, String>,
pub is_chaos: bool,
pub is_sessions: bool,
}Expand description
Configuration for the results writing process.
Fields
print_to_cli: boolDetermines whether the results should also be printed to the command-line interface.
output_file: FileThe file handle to which the measurement results should be written.
metadata_args: MetadataArgs<'a>Metadata for the measurement, to be written at the beginning of the output file.
m_type: MeasurementTypeMeasurement type
is_multi_origin: boolIndicates whether the measurement involves multiple origins
worker_map: BiHashMap<u32, String>A bidirectional map used to convert worker IDs (u16) to their corresponding hostnames (String).
is_chaos: boolIndicate whether any Origin is for CHAOS
is_sessions: boolWhether feed sessions are enabled (–sessions; adds a ‘session’ column to feed output)